@@ -2,5 +2,5 @@ use check_keyword::CheckKeyword;
 
 #[test]
 fn interface() {
-    assert_eq!("match".to_safe(), "r#match");
+    assert_eq!("match".into_safe(), "r#match");
 }
\ No newline at end of file
